ndt-dev - [ndt-dev] [ndt] r908 committed - Merged FlashIssue110 branch into trunk
Subject: NDT-DEV email list created
List archive
- From:
- To:
- Subject: [ndt-dev] [ndt] r908 committed - Merged FlashIssue110 branch into trunk
- Date: Thu, 13 Feb 2014 06:22:32 +0000
Revision: 908
Author:
Date: Thu Feb 13 06:22:16 2014 UTC
Log: Merged FlashIssue110 branch into trunk
http://code.google.com/p/ndt/source/detail?r=908
Added:
/trunk/tcpbw100-java.template
Modified:
/trunk
/trunk/Makefile.am
/trunk/conf/create-html.sh
Replaced:
/trunk/tcpbw100.template
=======================================
--- /dev/null
+++ /trunk/tcpbw100-java.template Thu Feb 13 06:22:16 2014 UTC
@@ -0,0 +1,96 @@
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+<html>
+<head>
+<title>YOURSITE NDT server</title>
+<meta http-equiv="Content-Language" content="en">
+<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+</head>
+<body onload="setTimeout('setUserAgent()', 2000)">
+<h3> YOURSITE Web100 based Network Diagnostic Tool (NDT) </h3>
+<b>Located at YOURLOCATION;
+YOURSPEED network connection</b>
+<br><font size=-1>
+ This is java version of client. If you want to use flash app instead, please visit <a href="tcpbw100.html">this site</a>
+<!-- this applet will email results to the person specified by the
+ param parameters. The 'H' value is the hostname, the 'U' value
+ is the username. The 'subject' line overwrites the default message
+ built into the java program. -->
+
+<table align=center><tr><td>
+<applet code="edu.internet2.ndt.Tcpbw100.class" name="NDTApplet" ARCHIVE="Tcpbw100.jar"
+ width=700 height=320>
+ <PARAM NAME="H" VALUE="YOURDOMAIN">
+ <PARAM NAME="U" VALUE="YOUREMAIL">
+ <PARAM NAME="subject" VALUE="YOURSUBJECT">
+
+<!--
+ JZ 2/14/2013: Localization Support
+
+ Greek/Greece
+ <PARAM NAME="language" VALUE="el">
+ <PARAM NAME="country" VALUE="GR">
+
+ Norwegian/Norway
+ <PARAM NAME="language" VALUE="nb">
+ <PARAM NAME="country" VALUE="NO">
+
+ Dutch/Netherlands
+ <PARAM NAME="language" VALUE="nl">
+ <PARAM NAME="country" VALUE="NL">
+
+ Catalan/Spain
+ <PARAM NAME="language" VALUE="ca">
+ <PARAM NAME="country" VALUE="ES">
+
+ Russian/Russia
+ <PARAM NAME="language" VALUE="ru">
+ <PARAM NAME="country" VALUE="RU">
+
+ French/France
+ <PARAM NAME="language" VALUE="fr">
+ <PARAM NAME="country" VALUE="FR">
+
+ Portugese/Brazil
+ <PARAM NAME="language" VALUE="pt">
+ <PARAM NAME="country" VALUE="BR">
+
+ English/US
+ <PARAM NAME="language" VALUE="en">
+ <PARAM NAME="country" VALUE="US">
+-->
+
+ <PARAM NAME="language" VALUE="en">
+ <PARAM NAME="country" VALUE="US">
+ <PARAM NAME="client" VALUE="applet">
+
+</applet>
+</td></tr></table>
+
+<br>
+<a
href="mailto:YOUREMAIL@YOURDOMAIN?subject=YOURSUBJECT
+?&body=Your name: %0aEmail: %0aHostname: %0a%0aPaste results from%20
+'Statistics' window here:%0a%0a%0aPaste results from 'More Details' window%20
+here:%0a%0a%0aComments:%0a">Report Problems</a> <font size=-1> Use "ctrl-C"
+to copy data onto the clipboard and then paste it into the email message. </font>
+
+<hr size=3 width="99%" noshade>
+<br>
+This java applet was originally developed by ORNL and has been extensively modified
+at ANL.
+<br>
+Complete University of Chicago <a href="copyright.html">Copyright Notice</a>
+<hr noshade width="90%" size=-4>
+Comments to <a href="mailto:"> Rich Carlson </a> email:
+<br><i>Created: April 4, 2002 by Rich Carlson
+<br>Last Updated: March 16, 2010 by Jason Zurawski</i>
+
+<script language="javascript" type="text/javascript">
+
+ function setUserAgent() {
+ document.NDTApplet.setUserAgent(navigator.userAgent);
+ }
+
+</script>
+
+</body>
+</html>
=======================================
--- /trunk/Makefile.am Wed Feb 5 13:31:05 2014 UTC
+++ /trunk/Makefile.am Thu Feb 13 06:22:16 2014 UTC
@@ -30,7 +30,7 @@
endif
EXTRA_DIST = admin_description.html admin.html \
- tcpbw100.template copyright.html web100variables.html \
+ tcpbw100.template tcpbw100-java.template copyright.html web100variables.html \
web100_variables COPYRIGHT \
DISCUSSION-LIST FILES Readme-fakewww Readme-web100srv \
contrib/README contrib/loadmap.intro contrib/loadmap.js \
=======================================
--- /trunk/conf/create-html.sh Fri Mar 28 16:19:35 2008 UTC
+++ /trunk/conf/create-html.sh Thu Feb 13 06:22:16 2014 UTC
@@ -1,14 +1,14 @@
#!/bin/bash
# This script creates the basic tcpbw100.html page needed by
# the NDT server.
#
# First prompt the user for some local data variables, site name
# and location, email address and subject line for reports, and
# the local link connection info.
#
# Then create the html file using the tcpbw100.template file
# modified by sed.
#
# Richard Carlson
#
@@ -16,7 +16,7 @@
#
echo "Welcome to the NDT server configuration program. This"
-echo "program will create a custom tcpbw100.html file for your site."
+echo "program will create a custom tcpbw100.html and tcpbw100-java.html files for your site."
echo ""
echo -n "Enter your site name [Internet2] : "
@@ -73,20 +73,27 @@
if test -f tcpbw100.template ; then
- TEMPLATE=tcpbw100.template
+ TEMPLATE_FLASH=../tcpbw100.template
+elif test -f ../tcpbw100.template ; then
+ TEMPLATE_FLASH=../tcpbw100.template
+fi
+
+if test -f tcpbw100-java.template ; then
+ TEMPLATE_JAVA=tcpbw100-java.template
elif test -f ../tcpbw100.template ; then
- TEMPLATE=../tcpbw100.template
+ TEMPLATE_JAVA=../tcpbw100-java.template
fi
# /bin/sed -f /tmp/$$ tcpbw100.template > tcpbw100.html
-/bin/sed -f /tmp/$$ $TEMPLATE > tcpbw100.html
+/bin/sed -f /tmp/$$ $TEMPLATE_FLASH > tcpbw100.html
+/bin/sed -f /tmp/$$ $TEMPLATE_JAVA > tcpbw100-java.html
/bin/rm -f /tmp/$$
-echo "The base web page 'tcpbw100.html' has now been created. You"
-echo "must move this file into the ndt_DATA directory [/usr/local/ndt]"
+echo "The base web pages 'tcpbw100.html' (with java applet) and 'tcpbw100-java.html (with flash client) has now been created. You"
+echo "must move these files into the ndt_DATA directory [/usr/local/ndt]"
echo "created during the 'make' process."
-echo -n "Do you want to install this file now? [yes] : "
+echo -n "Do you want to install these files now? [yes] : "
read answer
if test "$answer" = "n" -o "$answer" = "no"; then
exit
@@ -100,7 +107,7 @@
if test -w $answer; then
/bin/cp -p tcpbw100.html $answer
-
+ /bin/cp -p tcpbw100-java.html $answer
# create a default directory to store snaplog and tcpdump files in
if test ! -d $answer/serverdata; then
/bin/mkdir $answer/serverdata
- [ndt-dev] [ndt] r908 committed - Merged FlashIssue110 branch into trunk, ndt, 02/13/2014
Archive powered by MHonArc 2.6.16.
@@ -1,14 +1,14 @@
#!/bin/bash
-# This script creates the basic tcpbw100.html page needed by
+# This script creates the basic tcpbw100.html and tcpbw100-java.html pages needed by
# the NDT server.
#
@@ -1,14 +1,14 @@
# the local link connection info.
#
-# Then create the html file using the tcpbw100.template file
-# modified by sed.
+# Then create the html files using the tcpbw100.template (for page with flash client)
+# and tcpbw100-java.template (for page with java applet) files modified by sed.
#
# Richard Carlson